@@ -187,5 +187,15 @@ class TaggedItem(GenericTaggedItemBase, TaggedItemBase):
         verbose_name = _("tagged item")
         verbose_name_plural = _("tagged items")
         app_label = "taggit"
-        index_together = [["content_type", "object_id"]]
-        unique_together = [["content_type", "object_id", "tag"]]
+        indexes = [
+            models.Index(
+                fields=["content_type", "object_id"],
+            )
+        ]
+
+        constraints = [
+            models.UniqueConstraint(
+                fields=("content_type", "object_id", "tag"),
+                name="taggit_taggeditem_content_type_id_object_id_tag_id_4bb97a8e_uniq",
+            )
+        ]
