@@ -57,6 +57,8 @@ from .models import (
     TaggedCustomPKFood,
     TaggedFood,
     TaggedTrackedFood,
+    TenantModel,
+    TenantTag,
     TrackedTag,
     UUIDFood,
     UUIDHousePet,
@@ -65,6 +67,9 @@ from .models import (
     UUIDTaggedItem,
 )
 
+if DJANGO_VERSION < (4, 2):
+    TestCase.assertQuerySetEqual = TestCase.assertQuerysetEqual
+
 
 class BaseTaggingTestCase(TestCase):
     def assert_tags_equal(self, qs, tags, sort=True, attr="name"):
@@ -589,7 +594,7 @@ class TaggableManagerTestCase(BaseTaggingTestCase):
 
         pks = self.pet_model.objects.filter(tags__name__in=["fuzzy"])
         model_name = self.pet_model.__name__
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             pks,
             [f"<{model_name}: kitty>", f"<{model_name}: cat>"],
             ordered=False,
@@ -607,7 +612,7 @@ class TaggableManagerTestCase(BaseTaggingTestCase):
 
         pks = self.food_model.objects.exclude(tags__name__in=["red"])
         model_name = self.food_model.__name__
-        self.assertQuerysetEqual(
+        self.assertQuerySetEqual(
             pks,
             [f"<{model_name}: pear>", f"<{model_name}: guava>"],
             ordered=False,
@@ -842,6 +847,42 @@ class TaggableManagerUUIDTestCase(TaggableManagerTestCase):
         pass
 
 
+class TenantTagTestCase(TestCase):
+    model = TenantModel
+    tag_model = TenantTag
+
+    def test_tenant_tag(self):
+        tenant_1 = self.model.objects.create(name="tenant 1")
+        tenant_2 = self.model.objects.create(name="tenant 2")
+
+        # tenant 1 tags
+        tenant_1.tags.add("foo", "bar", tag_kwargs={"tenant_id": 1})
+
+        # tenant 2 tags
+        tenant_2.tags.add("foo", "baz", tag_kwargs={"tenant_id": 2})
+
+        # We should end up with 4 tags
+        self.assertEqual(self.tag_model.objects.all().count(), 4)
+        self.assertEqual(tenant_1.tags.count(), 2)
+        self.assertEqual(tenant_2.tags.count(), 2)
+
+    @override_settings(TAGGIT_CASE_INSENSITIVE=True)
+    def test_tenant_tag_insensitive(self):
+        tenant_1 = self.model.objects.create(name="tenant 1")
+        tenant_2 = self.model.objects.create(name="tenant 2")
+
+        # tenant 1 tags
+        tenant_1.tags.add("foo", "bar", tag_kwargs={"tenant_id": 1})
+
+        # tenant 2 tags
+        tenant_2.tags.add("foo", "baz", tag_kwargs={"tenant_id": 2})
+
+        # We should end up with 4 tags
+        self.assertEqual(self.tag_model.objects.all().count(), 4)
+        self.assertEqual(tenant_1.tags.count(), 2)
+        self.assertEqual(tenant_2.tags.count(), 2)
+
+
 class TaggableManagerOfficialTestCase(TaggableManagerTestCase):
     food_model = OfficialFood
     pet_model = OfficialPet
@@ -925,20 +966,23 @@ class TaggableFormTestCase(BaseTaggingTestCase):
             # https://github.com/django/django/commit/98756c685ee173bbd43f21ed0553f808be835ce5
             # https://github.com/django/django/commit/232b60a21b951bd16b8c95b34fcbcbf3ecd89fca
             form_str %= {
-                "help_start": '<div class="helptext">',
+                "help_start": '<div class="helptext" id="id_tags_helptext">',
                 "help_stop": "</div>",
                 "required": "required",
+                "aria": 'aria-describedby="id_tags_helptext"',
             }
         else:
             form_str %= {
                 "help_start": '<span class="helptext">',
                 "help_stop": "</span>",
                 "required": "required",
+                "aria": "",
             }
         return form_str
 
     def assertFormRenders(self, form, html):
-        self.assertHTMLEqual(str(form), self._get_form_str(html))
+        rendered_form = form.as_table() if DJANGO_VERSION < (5, 0) else form.as_div()
+        self.assertHTMLEqual(rendered_form, self._get_form_str(html))
 
     def test_form(self):
         self.assertEqual(list(self.form_class.base_fields), ["name", "tags"])
@@ -948,7 +992,7 @@ class TaggableFormTestCase(BaseTaggingTestCase):
             self.assertFormRenders(
                 f,
                 """<div><label for="id_name">Name:</label><input id="id_name" type="text" name="name" value="apple" maxlength="50" %(required)s /></div>
-    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input type="text" name="tags" value="green, red, yummy" id="id_tags" %(required)s /></div>""",
+    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input %(aria)s type="text" name="tags" value="green, red, yummy" id="id_tags" %(required)s /></div>""",
             )
         else:
             self.assertFormRenders(
@@ -976,7 +1020,7 @@ class TaggableFormTestCase(BaseTaggingTestCase):
             self.assertFormRenders(
                 f,
                 """<div><label for="id_name">Name:</label><input id="id_name" type="text" name="name" value="apple" maxlength="50" %(required)s /></div>
-    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input type="text" name="tags" value="delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
+    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input %(aria)s type="text" name="tags" value="delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
             )
         else:
             self.assertFormRenders(
@@ -991,7 +1035,7 @@ class TaggableFormTestCase(BaseTaggingTestCase):
             self.assertFormRenders(
                 f,
                 """<div><label for="id_name">Name:</label><input id="id_name" type="text" name="name" value="apple" maxlength="50" %(required)s /></div>
-    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input type="text" name="tags" value="&quot;has,comma&quot;, delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
+    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input %(aria)s type="text" name="tags" value="&quot;has,comma&quot;, delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
             )
         else:
             self.assertFormRenders(
@@ -1006,7 +1050,7 @@ class TaggableFormTestCase(BaseTaggingTestCase):
             self.assertFormRenders(
                 f,
                 """<div><label for="id_name">Name:</label><input id="id_name" type="text" name="name" value="apple" maxlength="50" %(required)s /></div>
-    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input type="text" name="tags" value="&quot;has space&quot;, &quot;has,comma&quot;, delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
+    <div><label for="id_tags">Tags:</label>%(help_start)sA comma-separated list of tags.%(help_stop)s<input %(aria)s type="text" name="tags" value="&quot;has space&quot;, &quot;has,comma&quot;, delicious, green, red, yummy" id="id_tags" %(required)s /></div>""",
             )
         else:
             self.assertFormRenders(
@@ -1324,3 +1368,8 @@ class PendingMigrationsTests(TestCase):
         out = StringIO()
         call_command("makemigrations", "taggit", dry_run=True, stdout=out)
         self.assertEqual(out.getvalue().strip(), "No changes detected in app 'taggit'")
+
+    def test_tests_have_no_pending_migrations(self):
+        out = StringIO()
+        call_command("makemigrations", "tests", dry_run=True, stdout=out)
+        self.assertEqual(out.getvalue().strip(), "No changes detected in app 'tests'")
